Module clock

Module clock 

For controlling time in programs, to make them testable over time periods.

Structs

FakeClock
A substute for the real clock for testing purposes, can be cloned but still refer to the same shared time, which can be updated centrally from tests.

Enums

Clock