FakeClock

Struct FakeClock 

pub struct FakeClock { /* private fields */ }
A substute for the real clock for testing purposes, can be cloned but still refer to the same shared time, which can be updated centrally from tests.

Implementations

Source

impl FakeClock

pub fn new(time: Instant) -> Self

pub fn add_days(&self, value: u32)

pub fn set_time(&self, time: Instant)

pub fn now(&self) -> Instant