pub struct DateParseError(pub String);Expand description
Error returned when a date string cannot be parsed.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for DateParseError
impl Clone for DateParseError
Sourcefn clone(&self) -> DateParseError
fn clone(&self) -> DateParseError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DateParseError
impl Debug for DateParseError
Sourceimpl Display for DateParseError
impl Display for DateParseError
Sourceimpl Error for DateParseError
impl Error for DateParseError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for DateParseError
impl PartialEq for DateParseError
Sourcefn eq(&self, other: &DateParseError) -> bool
fn eq(&self, other: &DateParseError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DateParseError
impl StructuralPartialEq for DateParseError