pub struct PeriodParseError(pub String);Expand description
Error returned when a period string cannot be parsed.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for PeriodParseError
impl Clone for PeriodParseError
Sourcefn clone(&self) -> PeriodParseError
fn clone(&self) -> PeriodParseError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeriodParseError
impl Debug for PeriodParseError
Sourceimpl Display for PeriodParseError
impl Display for PeriodParseError
Sourceimpl Error for PeriodParseError
impl Error for PeriodParseError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for PeriodParseError
impl PartialEq for PeriodParseError
Sourcefn eq(&self, other: &PeriodParseError) -> bool
fn eq(&self, other: &PeriodParseError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PeriodParseError
impl StructuralPartialEq for PeriodParseError