RecurrenceSchedule

Enum RecurrenceSchedule 

pub enum RecurrenceSchedule {
    Daily(DailyRecurrenceSchedule),
    Weekly(WeeklyRecurrenceSchedule),
    Monthly(MonthlyRecurrenceSchedule),
    Yearly(YearlyRecurrenceSchedule),
}

Variants

Implementations

Source

impl RecurrenceSchedule

pub fn inner(&self) -> &dyn Schedule

pub fn inner_mut(&mut self) -> &mut dyn Schedule

pub fn parse(value: &str, starting: Date) -> Result<Self, Error>

Parses the given string in relation to the given starting date. The starting date is important in situations where the weekday or day is implied, like every 2 weeks will check the starting for the day of the week on which the schedule fallse.

Errors

When given a string not in the expected format.

pub fn validate(value: &str) -> bool

Validates whether the given string is a valid recurrence schedule.

pub fn every_two_weeks(starting: Date) -> Self

Creates a schedule that is every two weeks from the starting date.

Panics

Should not panic; panic is used when the internal hard coded value does not fit the invariants.

pub fn daily() -> Self

pub fn weekly(starting: Date) -> Self

pub fn weekly_on(day: Weekday) -> Self

pub fn weekly_on_same_day_as(date: Date) -> Self

pub fn monthly(starting: Date) -> Self

pub fn quarterly(starting: Date) -> Self

Creates a recurrence schedule that is quarterly after each starting date.

Panics

When the literal values used inside this function aren’t allowed as invariants.

pub fn yearly(starting: Date) -> Self

pub fn common(starting: Date) -> Vec<RecurrenceSchedule>

The common set of recurrence schedules based on the given starting date.

pub fn default_for_unit(value: TemporalUnit, starting: Date) -> Self

pub fn into_weekly(self) -> Option<WeeklyRecurrenceSchedule>

pub fn into_monthly(self) -> Option<MonthlyRecurrenceSchedule>