WeeklyRecurrenceSchedule

Struct WeeklyRecurrenceSchedule 

pub struct WeeklyRecurrenceSchedule { /* private fields */ }

Implementations

Source

impl WeeklyRecurrenceSchedule

pub fn new(interval: Interval, days: impl Into<NonEmpty<Weekday>>) -> Self

pub fn for_weekday(interval: Interval, day: Weekday) -> Self

pub fn every_two_weeks(starting: Date) -> Self

Creates a schedule that is every two weeks from the starting date.

Panics

Should not panic; panic is used when the internal hard coded value does not fit the invariants.

pub fn weekly_on(day: Weekday) -> Self

pub fn with_weekday_toggled(self, weekday: Weekday) -> Self

Toggles the weekday to be included in the schedule if it’s not included, and excluded if it is already included. If the given weekday is the last weekday in the schedule, nothing will hapen.