pub struct FakeClock { /* private fields */ }Expand description
A substute for the real clock for testing purposes, can be cloned but still refer to the same shared time, which can be updated centrally from tests.
Implementations